==> google_cloud_documentai-1.3.0-py2.py3-none-any.whl: google/cloud/documentai_v1beta2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .document import Document
from .document_understanding import (
    AutoMlParams,
    BatchProcessDocumentsRequest,
    BatchProcessDocumentsResponse,
    EntityExtractionParams,
    FormExtractionParams,
    GcsDestination,
    GcsSource,
    InputConfig,
    KeyValuePairHint,
    OcrParams,
    OperationMetadata,
    OutputConfig,
    ProcessDocumentRequest,
    ProcessDocumentResponse,
    TableBoundHint,
    TableExtractionParams,
)
from .geometry import (
    BoundingPoly,
    NormalizedVertex,
    Vertex,
)

__all__ = (
    "Document",
    "AutoMlParams",
    "BatchProcessDocumentsRequest",
    "BatchProcessDocumentsResponse",
    "EntityExtractionParams",
    "FormExtractionParams",
    "GcsDestination",
    "GcsSource",
    "InputConfig",
    "KeyValuePairHint",
    "OcrParams",
    "OperationMetadata",
    "OutputConfig",
    "ProcessDocumentRequest",
    "ProcessDocumentResponse",
    "TableBoundHint",
    "TableExtractionParams",
    "BoundingPoly",
    "NormalizedVertex",
    "Vertex",
)

==> google_cloud_documentai-2.24.2-py2.py3-none-any.whl: google/cloud/documentai_v1beta2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .barcode import Barcode
from .document import Document
from .document_understanding import (
    AutoMlParams,
    BatchProcessDocumentsRequest,
    BatchProcessDocumentsResponse,
    EntityExtractionParams,
    FormExtractionParams,
    GcsDestination,
    GcsSource,
    InputConfig,
    KeyValuePairHint,
    OcrParams,
    OperationMetadata,
    OutputConfig,
    ProcessDocumentRequest,
    ProcessDocumentResponse,
    TableBoundHint,
    TableExtractionParams,
)
from .geometry import BoundingPoly, NormalizedVertex, Vertex

__all__ = (
    "Barcode",
    "Document",
    "AutoMlParams",
    "BatchProcessDocumentsRequest",
    "BatchProcessDocumentsResponse",
    "EntityExtractionParams",
    "FormExtractionParams",
    "GcsDestination",
    "GcsSource",
    "InputConfig",
    "KeyValuePairHint",
    "OcrParams",
    "OperationMetadata",
    "OutputConfig",
    "ProcessDocumentRequest",
    "ProcessDocumentResponse",
    "TableBoundHint",
    "TableExtractionParams",
    "BoundingPoly",
    "NormalizedVertex",
    "Vertex",
)
